@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995-2005, Index Data.
+ * Copyright (C) 1995-2005, Index Data ApS
  *
  * Permission to use, copy, modify, distribute, and sell this software and
  * its documentation, in whole or in part, for any purpose, is hereby granted,
@@ -23,7 +23,7 @@
  * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE
  * OF THIS SOFTWARE.
  *
- * $Id: backend.h,v 1.27 2005/01/11 12:07:55 adam Exp $
+ * $Id: backend.h,v 1.30 2005/03/03 23:16:20 adam Exp $
  */
 
 /** 
@@ -201,6 +201,7 @@ typedef struct {
     char *explain_buf;
     char *database;
     char *schema;
+    void *server_node_ptr;
 } bend_explain_rr;
 
 typedef struct bend_initrequest
@@ -286,6 +287,7 @@ typedef struct statserv_options_block
     char pid_fname[128];            /* pid fname */
     int background;                 /* auto daemon */
     char cert_fname[128];           /* SSL certificate fname */
+    char xml_config[128];           /* XML config filename */
 } statserv_options_block;
 
 YAZ_EXPORT int statserv_main(
